Estimates the shape parameters for a beta distribution using
Usage
fitbeta(x, range = c(0, 1), na.rm = FALSE)Value
mean, mode, and median (sorted by their values), and the variance
of the beta distribution fitted to x.
Estimates the shape parameters for a beta distribution using
fitbeta(x, range = c(0, 1), na.rm = FALSE)mean, mode, and median (sorted by their values), and the variance
of the beta distribution fitted to x.